# encoding: UTF-8
class Epoch < ActiveRecord::Base
  has_paper_trail
  include Uuidextension
  belongs_to :owner
  has_many :transfers

  attr_accessible :name, :description, :starts_at, :ends_sat, :owner
  validates :name, :presence => true
  validates :owner, :presence => true
  validate :data_jsou_spravne_serazena

  attr_accessible :name, :description, :starts_at, :ends_at, :owner, :owner_id

  default_scope order('starts_at')
  has_many :later_epochs, :class_name=>Epoch, :through=>:owners, :source=>:epoch  

  def self.get_default_for(transfer)
    res = transfer.owner.epochs.where("? BETWEEN starts_at AND ends_at", transfer.datum).first
    if !res
      year = transfer.datum.year
      res = Epoch.create(:name => "E#{year}", :description=>"#{transfer.owner} - hospodářský rok #{year}", :starts_at=> Date.new(year,1,1), :ends_at=> Date.new(year,12,31), :owner=>transfer.owner)
    end
    return res
  end

  def year
    starts_at.year
  end

  def contains(datum)
    !datum.nil? and (starts_at <= datum) and (datum <= ends_at)
  end
  
  def to_s
    description
  end
  
  def daterange
    if starts_at.year == ends_at.year
      "#{starts_at.strftime('%-d.%-m.')}-#{ends_at.strftime('%-d.%-m. %Y')}" 
    else
      "#{starts_at.strftime('%-d.%-m.%y')} - #{ends_at.strftime('%-d.%-m.%y')}"     
    end    
  end
  
  def data_jsou_spravne_serazena
    errors.add(:stars_at, "Datum začátku musí být před datem konce") if starts_at>ends_at
  end
end
